"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.depositNearV1 = exports.withdrawV1 = exports.withdrawFtV1 = exports.withdrawNearV1 = exports.cancelAllOrdersV1 = exports.cancelOrderV1 = exports.placeOrderV1 = exports.createMarketV1 = exports.batchV1 = exports.prepareNewOrderV1 = void 0;
/**
 * Helper functions for creating ready-to-sign transactions.
 */
const utils_1 = require("@tonic-foundation/utils");
const bn_js_1 = __importDefault(require("bn.js"));
const token_1 = require("./token");
const util_1 = require("./util");
const shim_1 = require("@tonic-foundation/transaction/lib/shim");
function prepareNewOrderV1(params) {
    var _a, _b;
    return Object.assign(Object.assign({}, params), { max_spend: (_a = params.max_spend) === null || _a === void 0 ? void 0 : _a.toString(), limit_price: (_b = params.limit_price) === null || _b === void 0 ? void 0 : _b.toString(), quantity: params.quantity.toString() });
}
exports.prepareNewOrderV1 = prepareNewOrderV1;
function batchV1(contractId, batch) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'execute',
        args: {
            actions: batch.prepare(),
        },
        gas: (0, utils_1.tgasAmount)(300),
        attachedDeposit: new bn_js_1.default(1),
    });
}
exports.batchV1 = batchV1;
function createMarketV1(contractId, params) {
    const base_token = (0, token_1.toInternalTokenId)(params.baseTokenId);
    const quote_token = (0, token_1.toInternalTokenId)(params.quoteTokenId);
    const args = {
        base_token,
        quote_token,
        base_token_lot_size: params.baseTokenLotSize,
        quote_token_lot_size: params.quoteTokenLotSize,
        taker_fee_base_rate: params.takerFeeBaseRate,
        maker_rebate_base_rate: params.makerRebateBaseRate,
    };
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'create_market',
        args: { args },
        gas: utils_1.MAX_GAS,
        attachedDeposit: (0, util_1.nearAmount)(0.1),
    });
}
exports.createMarketV1 = createMarketV1;
function placeOrderV1(contractId, market_id, order) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'new_order',
        args: {
            market_id,
            order: prepareNewOrderV1(order),
        },
        gas: utils_1.MAX_GAS,
    });
}
exports.placeOrderV1 = placeOrderV1;
function cancelOrderV1(contractId, market_id, order_id) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'cancel_order',
        args: {
            market_id,
            order_id,
        },
        gas: (0, utils_1.tgasAmount)(100),
    });
}
exports.cancelOrderV1 = cancelOrderV1;
function cancelAllOrdersV1(contractId, market_id) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'cancel_all_orders',
        args: { market_id },
        gas: utils_1.MAX_GAS,
    });
}
exports.cancelAllOrdersV1 = cancelAllOrdersV1;
function withdrawNearV1(contractId, amount) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'withdraw_near',
        args: {
            amount: amount.toString(),
        },
        gas: utils_1.MAX_GAS,
        attachedDeposit: new bn_js_1.default(1),
    });
}
exports.withdrawNearV1 = withdrawNearV1;
function withdrawFtV1(contractId, tokenId, amount) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'withdraw_ft',
        args: {
            token: tokenId,
            amount: amount.toString(),
        },
        gas: utils_1.MAX_GAS,
        attachedDeposit: new bn_js_1.default(1),
    });
}
exports.withdrawFtV1 = withdrawFtV1;
function withdrawV1(contractId, tokenId, amount) {
    if (tokenId.toUpperCase() === 'NEAR') {
        return withdrawNearV1(contractId, amount);
    }
    else {
        return withdrawFtV1(contractId, tokenId, amount);
    }
}
exports.withdrawV1 = withdrawV1;
function depositNearV1(contractId, amount) {
    return new shim_1.StandardNearFunctionCall({
        contractId,
        methodName: 'deposit_near',
        args: {},
        attachedDeposit: amount,
        gas: utils_1.MAX_GAS,
    });
}
exports.depositNearV1 = depositNearV1;
